@@ -84,6 +84,7 @@ FLAVOR_PROFILE_ID = 'flavor_profile_id'
 
 # Other constants
 ACTIVE = 'ACTIVE'
+PENDING_UPDATE = 'PENDING_UPDATE'
 ADMIN_STATE_UP_TRUE = 'true'
 ASC = 'asc'
 DELETED = 'DELETED'
@@ -101,6 +102,7 @@ ACTIVE_STANDBY = 'ACTIVE_STANDBY'
 HTTP = 'HTTP'
 HTTPS = 'HTTPS'
 TCP = 'TCP'
+TERMINATED_HTTPS = 'TERMINATED_HTTPS'
 
 # HTTP Methods
 GET = 'GET'
