@@ -127,6 +127,7 @@ class LoadBalancerBaseTest(test.BaseTestCase):
         cls.lb_admin_flavor_client = cls.os_roles_lb_admin.flavor_client
         cls.mem_flavor_client = cls.os_roles_lb_member.flavor_client
         cls.mem_provider_client = cls.os_roles_lb_member.provider_client
+        cls.os_admin_servers_client = cls.os_admin.servers_client
 
     @classmethod
     def resource_setup(cls):
@@ -298,14 +299,14 @@ class LoadBalancerBaseTest(test.BaseTestCase):
 
         # Create tenant VIP IPv6 subnet
         if CONF.load_balancer.test_with_ipv6:
-            # See if ipv6-public-subnet exists and use it if so.
-            pub_ipv6_subnet = cls.os_admin.subnets_client.list_subnets(
-                name='ipv6-public-subnet')['subnets']
+            # See if ipv6-private-subnet exists and use it if so.
+            priv_ipv6_subnet = cls.os_admin.subnets_client.list_subnets(
+                name='ipv6-private-subnet')['subnets']
 
-            if len(pub_ipv6_subnet) == 1:
-                cls.lb_member_vip_ipv6_subnet = pub_ipv6_subnet[0]
+            if len(priv_ipv6_subnet) == 1:
+                cls.lb_member_vip_ipv6_subnet = priv_ipv6_subnet[0]
                 cls.lb_member_vip_ipv6_net = {
-                    'id': pub_ipv6_subnet[0]['network_id']}
+                    'id': priv_ipv6_subnet[0]['network_id']}
             else:
                 subnet_kwargs = {
                     'name': data_utils.rand_name("lb_member_vip_ipv6_subnet"),
@@ -314,6 +315,7 @@ class LoadBalancerBaseTest(test.BaseTestCase):
                     'ip_version': 6}
                 result = cls.lb_mem_subnet_client.create_subnet(
                     **subnet_kwargs)
+                cls.lb_member_vip_ipv6_net = cls.lb_member_vip_net
                 cls.lb_member_vip_ipv6_subnet = result['subnet']
                 cls.addClassResourceCleanup(
                     waiters.wait_for_not_found,
